==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/StrengthenTableBlock.java <==
package cc.thonly.reverie_dreams.block;

import cc.thonly.reverie_dreams.block.entity.StrengthenTableBlockEntity;
import cc.thonly.reverie_dreams.gui.recipe.block.StrengthTableGui;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_1269;
import net.minecraft.class_1277;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3965;
import org.jetbrains.annotations.Nullable;

public class StrengthenTableBlock extends class_2237 {

    protected StrengthenTableBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    protected class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!world.field_9236 && player instanceof class_3222 serverPlayer) {
            player.method_23667(player.method_6058(), true);
            StrengthenTableBlockEntity blockEntity = (StrengthenTableBlockEntity) world.method_8321(pos);
            StrengthTableGui gui = new StrengthTableGui(serverPlayer, blockEntity, false);
            gui.open();
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

    @Override
    public class_2680 method_9576(class_1937 world, class_2338 pos, class_2680 state, class_1657 player) {
        class_2586 blockEntity = world.method_8321(pos);
        if (blockEntity instanceof StrengthenTableBlockEntity STBE) {
            class_1277 inventory = STBE.getInventory();
            for (int i = 0; i < inventory.method_5439(); i++) {
                class_1799 stack = inventory.method_5438(i);
                class_1542 itemEntity = new class_1542(world, pos.method_10263(), pos.method_10264(), pos.method_10260(), stack.method_7972());
                world.method_8649(itemEntity);
            }
        }
        return super.method_9576(world, pos, state, player);
    }

    @Override
    protected MapCodec<? extends class_2237> method_53969() {
        return method_54094(StrengthenTableBlock::new);
    }

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new StrengthenTableBlockEntity(pos, state);
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/StrengthenTableBlock.java <==
package cc.thonly.reverie_dreams.block;

import cc.thonly.reverie_dreams.block.entity.StrengthenTableBlockEntity;
import cc.thonly.reverie_dreams.gui.recipe.gui.StrengthTableGui;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_1269;
import net.minecraft.class_1277;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3965;
import org.jetbrains.annotations.Nullable;

public class StrengthenTableBlock extends class_2237 {

    public StrengthenTableBlock(class_2251 settings) {
        super(settings);
    }

    @Override
    protected class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!world.field_9236 && player instanceof class_3222 serverPlayer) {
            player.method_23667(player.method_6058(), true);
            StrengthenTableBlockEntity blockEntity = (StrengthenTableBlockEntity) world.method_8321(pos);
            StrengthTableGui gui = new StrengthTableGui(serverPlayer, blockEntity, false);
            gui.open();
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

    @Override
    public class_2680 method_9576(class_1937 world, class_2338 pos, class_2680 state, class_1657 player) {
        class_2586 blockEntity = world.method_8321(pos);
        if (blockEntity instanceof StrengthenTableBlockEntity STBE) {
            class_1277 inventory = STBE.getInventory();
            for (int i = 0; i < inventory.method_5439(); i++) {
                class_1799 stack = inventory.method_5438(i);
                class_1542 itemEntity = new class_1542(world, pos.method_10263(), pos.method_10264(), pos.method_10260(), stack.method_7972());
                world.method_8649(itemEntity);
            }
        }
        return super.method_9576(world, pos, state, player);
    }

    @Override
    protected MapCodec<? extends class_2237> method_53969() {
        return method_54094(StrengthenTableBlock::new);
    }

    @Nullable
    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new StrengthenTableBlockEntity(pos, state);
    }
}
